import java.io.IOException; 

/******************************************************************************
*  Frequency-weight table.
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2017-06-26
*  @version  1.00
******************************************************************************/

public class FreqWeightTable {

	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with record data. */
	static final String DATA_FILE = "FreqWeights.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static FreqWeightTable instance = null;
	
	/** Array of individual records. */
	FreqWeight[] array;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected FreqWeightTable () throws IOException {
		String[][] table = CSVReader.readFile(DATA_FILE);
		array = new FreqWeight[table.length - 1];
		for (int i = 0; i < table.length - 1; i++) {
			array[i] = new FreqWeight(table[i+1]);
		}
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------

	/**
	*  Access the singleton class instance.
	*/
	public static FreqWeightTable getInstance() {
		if (instance == null) {
			try {
				instance = new FreqWeightTable();
			}
			catch (IOException e) {
				System.err.println("Failed to read file " + DATA_FILE);
			}
		}
		return instance;
	}

	/**
	*  Get record for given frequency code.
	*/
	private FreqWeight getFreqWeightRecord (char code) {
		for (FreqWeight fw: array) {
			if (code == fw.getCode())
				return fw;
		}
		System.err.println("Error: Unmatched frequency code.");
		return null;
	}

	/**
	*  Get weighting for a given frequency code.
	*/
	public int getWeight (char code) {
		FreqWeight fw = getFreqWeightRecord(code);
		return fw == null ? 0 : fw.getWeight();		
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
		FreqWeightTable table = FreqWeightTable.getInstance();
		System.out.println("Code\tWeight");
		System.out.println("C\t" + table.getWeight('C'));
		System.out.println("U\t" + table.getWeight('U'));
		System.out.println("R\t" + table.getWeight('R'));
		System.out.println("V\t" + table.getWeight('V'));
	}
}

