import java.io.IOException; 

/******************************************************************************
*  Table of Intelligence records.
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2017-06-17
*  @version  1.01
******************************************************************************/

public class IntTable {

	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with record data. */
	static final String DATA_FILE = "Intelligence.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static IntTable instance = null;
	
	/** Array of individual records. */
	IntRecord[] array;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected IntTable () throws IOException {
		String[][] table = CSVReader.readFile(DATA_FILE);
		array = new IntRecord[table.length - 1];
		for (int i = 0; i < table.length - 1; i++) {
			array[i] = new IntRecord(table[i+1]);
		}
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------

	/**
	*  Access the singleton class instance.
	*/
	public static IntTable getInstance() {
		if (instance == null) {
			try {
				instance = new IntTable();
			}
			catch (IOException e) {
				System.err.println("Failed to read file " + DATA_FILE);
			}
		}
		return instance;
	}

	/**
	*  Get record for given Inteligence score.
	*/
	private IntRecord getIntelRecord (int intel) {
		for (int i = 0; i < array.length; i++) {
			if (i == array.length - 1 || intel < array[i+1].getIntKey())
				return array[i];
		}
		return null;
	}

	/**
	*  Get minimum spells for given Intelligence.
	*/
	public int getMinSpells (int intel) {
		return getIntelRecord(intel).getMinSpells();
	}

	/**
	*  Get maximum spells for given Intelligence.
	*/
	public int getMaxSpells (int intel) {
		return getIntelRecord(intel).getMaxSpells();
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
		IntTable table = IntTable.getInstance();
		System.out.println("Int\tMin\tMax");
		for (int intel = 1; intel <= 20; intel++) {
			System.out.print(intel);
			System.out.print("\t" + table.getMinSpells(intel));
			System.out.print("\t" + table.getMaxSpells(intel));
			System.out.println();						
		}
	}
}

