import java.io.IOException; 

/******************************************************************************
*  Table of Level Access values.
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2017-06-20
*  @version  1.00
******************************************************************************/

public class LevelAccessTable {

	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with record data. */
	static final String DATA_FILE = "LevelAccess.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static LevelAccessTable instance = null;
	
	/** Array of individual records. */
	int[] array;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected LevelAccessTable () throws IOException {
		String[][] table = CSVReader.readFile(DATA_FILE);
		array = new int[table.length - 1];
		for (int i = 0; i < table.length - 1; i++) {
			array[i] = Integer.parseInt(table[i+1][1]);
		}
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------

	/**
	*  Access the singleton class instance.
	*/
	public static LevelAccessTable getInstance() {
		if (instance == null) {
			try {
				instance = new LevelAccessTable();
			}
			catch (IOException e) {
				System.err.println("Failed to read file " + DATA_FILE);
			}
		}
		return instance;
	}

	/**
	*  Get max spell level for given wizard level.
	*/
	public int getMaxSpellLevel (int wizLevel) {
		for (int slevel = 0; slevel < array.length; slevel++) {
			if (wizLevel < array[slevel])
				return slevel;
		}
		return array.length;
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
		LevelAccessTable table = LevelAccessTable.getInstance();
		System.out.println("WizLevel\tMaxSpellLevel");
		for (int wizLevel = 0; wizLevel <= 20; wizLevel++) {
			System.out.print(wizLevel + "\t");
			System.out.print(table.getMaxSpellLevel(wizLevel));
			System.out.println();						
		}
	}
}

